import sphinx_rtd_theme

extensions = [
    "sphinx_rtd_theme",
    "sphinx.ext.napolean",
    "sphinx.ext.viewcode",
    "sphinx.ext.autodoc"
]

master_doc = "index"
html_theme = "sphinx_rtd_theme"

project = "animec"
copyright = "Copyright Drift Asimov"
author = "DriftAsimov"
version = release = "0.0.6"